Class: Time
- Inherits:
-
Object
- Object
- Time
- Defined in:
- lib/brightbox-cli/ruby_core_ext.rb
Instance Method Summary collapse
-
#clipped_iso8601 ⇒ String
Returns a shortened version of ISO 8601 omitting the seconds and timezone information.
- #to_s ⇒ Object
Instance Method Details
#clipped_iso8601 ⇒ String
Note:
This output is probably in error and should be updated however the missing characters will reformat a number of columns and pages of output.
Returns a shortened version of ISO 8601 omitting the seconds and timezone information.
10 11 12 |
# File 'lib/brightbox-cli/ruby_core_ext.rb', line 10 def clipped_iso8601 strftime(utc? ? "%Y-%m-%dT%H:%MZ" : "%Y-%m-%dT%H:%M") end |
#to_s ⇒ Object
14 15 16 |
# File 'lib/brightbox-cli/ruby_core_ext.rb', line 14 def to_s clipped_iso8601 end |